@@ -11,6 +11,8 @@ from .indexes import BaseIndex, Index, MultiIndex
 from .interfaces import get_interface
 from .interfaces.pandas import to_pandas
 
+RESERVED_FIELDS = ("limit", "skip", "sort")
+
 
 class EditError(Exception):
     pass
@@ -32,6 +34,12 @@ class BaseSchema(BaseModel):
     class Config:
         validate_assignment = True
 
+    def __init_subclass__(cls) -> None:
+        for name in RESERVED_FIELDS:
+            if name in cls.__fields__:
+                raise ValueError(f"Field name '{name}' is reserved and cannot be used.")
+        return super().__init_subclass__()
+
     @classmethod
     def default_datasource(cls):
         return cls.empty_dframe()
@@ -64,9 +72,11 @@ class BaseSchema(BaseModel):
                 if name in getattr(type_, "__annotations__", {}):
                     label_annotation = type_.__annotations__[name]
                     annotation = Optional[
-                        Union[label_annotation,
-                              List[label_annotation],
-                              Dict[str, Optional[label_annotation]]]
+                        Union[
+                            label_annotation,
+                            List[label_annotation],
+                            Dict[str, Optional[label_annotation]],
+                        ]
                     ]
                     param = inspect.Parameter(
                         name,
@@ -128,7 +138,7 @@ class BaseSchema(BaseModel):
             val, error = field.validate(val, validated, loc=name)
             if errors:
                 errors.append(error)
-                
+
             validated[name] = val
 
         if errors:
@@ -196,14 +206,14 @@ class BaseSchema(BaseModel):
 
     @classmethod
     def _find(
-        cls, datasource=None, _skip=None, _limit=None, _sort=None, **labels
+        cls, datasource=None, skip=None, limit=None, sort=None, **labels
     ) -> Generator[dict, None, None]:
         """Internal find function, performs data validation but
         returns raw dicts, not schema instances.
         """
 
         query = cls.compile_query(datasource=datasource, **labels)
-        for doc in query.iter(limit=_limit, skip=_skip, sort=_sort):
+        for doc in query.iter(limit=limit, skip=skip, sort=sort):
             try:
                 cls.validate(doc)
             except ValidationError:
@@ -212,7 +222,7 @@ class BaseSchema(BaseModel):
 
     @classmethod
     def find(
-        cls, datasource=None, _skip=None, _limit=None, _sort=None, **labels
+        cls, datasource=None, skip=None, limit=None, sort=None, **labels
     ) -> List["BaseSchema"]:
         """Find documents in datasource matching the given labels
         returns List[BaseSchema]
@@ -221,26 +231,22 @@ class BaseSchema(BaseModel):
         return [
             cls(**doc)
             for doc in cls._find(
-                datasource, _skip=_skip, _limit=_limit, _sort=_sort, **labels
+                datasource, skip=skip, limit=limit, sort=sort, **labels
             )
         ]
 
     @classmethod
-    def find_iter(cls, datasource=None, _skip=None, _limit=None, _sort=None, **labels):
-        for doc in cls._find(
-            datasource, _skip=_skip, _limit=_limit, _sort=_sort, **labels
-        ):
+    def find_iter(cls, datasource=None, skip=None, limit=None, sort=None, **labels):
+        for doc in cls._find(datasource, skip=skip, limit=limit, sort=sort, **labels):
             yield cls(**doc)
 
     @classmethod
     def find_df(
-        cls, datasource=None, _skip=None, _limit=None, _sort=None, **labels
+        cls, datasource=None, skip=None, limit=None, sort=None, **labels
     ) -> pd.DateOffset:
         docs = [
             to_pandas(d)
-            for d in cls._find(
-                datasource, _skip=_skip, _limit=_limit, _sort=_sort, **labels
-            )
+            for d in cls._find(datasource, skip=skip, limit=limit, sort=sort, **labels)
         ]
         df = pd.json_normalize(docs)
         if not len(df):
@@ -252,11 +258,9 @@ class BaseSchema(BaseModel):
 
     @classmethod
     def find_one(
-        cls, datasource=None, _skip=None, _sort=None, **labels
+        cls, datasource=None, skip=None, sort=None, **labels
     ) -> Optional["BaseSchema"]:
-        docs = cls.find(
-            datasource=datasource, _skip=_skip, _limit=1, _sort=_sort, **labels
-        )
+        docs = cls.find(datasource=datasource, skip=skip, limit=1, sort=sort, **labels)
         if docs:
             return docs[0]
         return None
